@@ -17,10 +17,14 @@ import logging
 import queue
 import threading
 
-import grpc
 import mock
 import pytest
 
+try:
+    import grpc
+except ImportError:  # pragma: NO COVER
+    pytest.skip("No GRPC", allow_module_level=True)
+
 from google.api_core import bidi
 from google.api_core import exceptions
 
@@ -800,6 +804,21 @@ class TestBackgroundConsumer(object):
         while consumer.is_active:
             pass
 
+    def test_rpc_callback_fires_when_consumer_start_fails(self):
+        expected_exception = exceptions.InvalidArgument(
+            "test", response=grpc.StatusCode.INVALID_ARGUMENT
+        )
+        callback = mock.Mock(spec=["__call__"])
+
+        rpc, _ = make_rpc()
+        bidi_rpc = bidi.BidiRpc(rpc)
+        bidi_rpc.add_done_callback(callback)
+        bidi_rpc._start_rpc.side_effect = expected_exception
+
+        consumer = bidi.BackgroundConsumer(bidi_rpc, on_response=None)
+        consumer.start()
+        assert callback.call_args.args[0] == grpc.StatusCode.INVALID_ARGUMENT
+
     def test_consumer_expected_error(self, caplog):
         caplog.set_level(logging.DEBUG)
 
@@ -836,7 +855,7 @@ class TestBackgroundConsumer(object):
 
         # Wait for the consumer's thread to exit.
         while consumer.is_active:
-            pass
+            pass  # pragma: NO COVER (race condition)
 
         on_response.assert_not_called()
         bidi_rpc.recv.assert_called_once()
