@@ -12,10 +12,14 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-import grpc
 import mock
 import pytest
 
+try:
+    import grpc
+except ImportError:  # pragma: NO COVER
+    pytest.skip("No GRPC", allow_module_level=True)
+
 from google.api_core import exceptions
 from google.api_core import grpc_helpers
 import google.auth.credentials
@@ -52,6 +56,9 @@ class RpcErrorImpl(grpc.RpcError, grpc.Call):
     def details(self):
         return None
 
+    def trailing_metadata(self):
+        return None
+
 
 def test_wrap_unary_errors():
     grpc_error = RpcErrorImpl(grpc.StatusCode.INVALID_ARGUMENT)
@@ -66,6 +73,145 @@ def test_wrap_unary_errors():
     assert exc_info.value.response == grpc_error
 
 
+class Test_StreamingResponseIterator:
+    @staticmethod
+    def _make_wrapped(*items):
+        return iter(items)
+
+    @staticmethod
+    def _make_one(wrapped, **kw):
+        return grpc_helpers._StreamingResponseIterator(wrapped, **kw)
+
+    def test_ctor_defaults(self):
+        wrapped = self._make_wrapped("a", "b", "c")
+        iterator = self._make_one(wrapped)
+        assert iterator._stored_first_result == "a"
+        assert list(wrapped) == ["b", "c"]
+
+    def test_ctor_explicit(self):
+        wrapped = self._make_wrapped("a", "b", "c")
+        iterator = self._make_one(wrapped, prefetch_first_result=False)
+        assert getattr(iterator, "_stored_first_result", self) is self
+        assert list(wrapped) == ["a", "b", "c"]
+
+    def test_ctor_w_rpc_error_on_prefetch(self):
+        wrapped = mock.MagicMock()
+        wrapped.__next__.side_effect = grpc.RpcError()
+
+        with pytest.raises(grpc.RpcError):
+            self._make_one(wrapped)
+
+    def test___iter__(self):
+        wrapped = self._make_wrapped("a", "b", "c")
+        iterator = self._make_one(wrapped)
+        assert iter(iterator) is iterator
+
+    def test___next___w_cached_first_result(self):
+        wrapped = self._make_wrapped("a", "b", "c")
+        iterator = self._make_one(wrapped)
+        assert next(iterator) == "a"
+        iterator = self._make_one(wrapped, prefetch_first_result=False)
+        assert next(iterator) == "b"
+        assert next(iterator) == "c"
+
+    def test___next___wo_cached_first_result(self):
+        wrapped = self._make_wrapped("a", "b", "c")
+        iterator = self._make_one(wrapped, prefetch_first_result=False)
+        assert next(iterator) == "a"
+        assert next(iterator) == "b"
+        assert next(iterator) == "c"
+
+    def test___next___w_rpc_error(self):
+        wrapped = mock.MagicMock()
+        wrapped.__next__.side_effect = grpc.RpcError()
+        iterator = self._make_one(wrapped, prefetch_first_result=False)
+
+        with pytest.raises(exceptions.GoogleAPICallError):
+            next(iterator)
+
+    def test_add_callback(self):
+        wrapped = mock.MagicMock()
+        callback = mock.Mock(spec={})
+        iterator = self._make_one(wrapped, prefetch_first_result=False)
+
+        assert iterator.add_callback(callback) is wrapped.add_callback.return_value
+
+        wrapped.add_callback.assert_called_once_with(callback)
+
+    def test_cancel(self):
+        wrapped = mock.MagicMock()
+        iterator = self._make_one(wrapped, prefetch_first_result=False)
+
+        assert iterator.cancel() is wrapped.cancel.return_value
+
+        wrapped.cancel.assert_called_once_with()
+
+    def test_code(self):
+        wrapped = mock.MagicMock()
+        iterator = self._make_one(wrapped, prefetch_first_result=False)
+
+        assert iterator.code() is wrapped.code.return_value
+
+        wrapped.code.assert_called_once_with()
+
+    def test_details(self):
+        wrapped = mock.MagicMock()
+        iterator = self._make_one(wrapped, prefetch_first_result=False)
+
+        assert iterator.details() is wrapped.details.return_value
+
+        wrapped.details.assert_called_once_with()
+
+    def test_initial_metadata(self):
+        wrapped = mock.MagicMock()
+        iterator = self._make_one(wrapped, prefetch_first_result=False)
+
+        assert iterator.initial_metadata() is wrapped.initial_metadata.return_value
+
+        wrapped.initial_metadata.assert_called_once_with()
+
+    def test_is_active(self):
+        wrapped = mock.MagicMock()
+        iterator = self._make_one(wrapped, prefetch_first_result=False)
+
+        assert iterator.is_active() is wrapped.is_active.return_value
+
+        wrapped.is_active.assert_called_once_with()
+
+    def test_time_remaining(self):
+        wrapped = mock.MagicMock()
+        iterator = self._make_one(wrapped, prefetch_first_result=False)
+
+        assert iterator.time_remaining() is wrapped.time_remaining.return_value
+
+        wrapped.time_remaining.assert_called_once_with()
+
+    def test_trailing_metadata(self):
+        wrapped = mock.MagicMock()
+        iterator = self._make_one(wrapped, prefetch_first_result=False)
+
+        assert iterator.trailing_metadata() is wrapped.trailing_metadata.return_value
+
+        wrapped.trailing_metadata.assert_called_once_with()
+
+
+class TestGrpcStream(Test_StreamingResponseIterator):
+    @staticmethod
+    def _make_one(wrapped, **kw):
+        return grpc_helpers.GrpcStream(wrapped, **kw)
+
+    def test_grpc_stream_attributes(self):
+        """
+        Should be both a grpc.Call and an iterable
+        """
+        call = self._make_one(None)
+        assert isinstance(call, grpc.Call)
+        # should implement __iter__
+        assert hasattr(call, "__iter__")
+        it = call.__iter__()
+        assert hasattr(it, "__next__")
+
+
 def test_wrap_stream_okay():
     expected_responses = [1, 2, 3]
     callable_ = mock.Mock(spec=["__call__"], return_value=iter(expected_responses))
@@ -93,7 +239,7 @@ def test_wrap_stream_prefetch_disabled():
     callable_.assert_called_once_with(1, 2, three="four")
 
 
-def test_wrap_stream_iterable_iterface():
+def test_wrap_stream_iterable_interface():
     response_iter = mock.create_autospec(grpc.Call, instance=True)
     callable_ = mock.Mock(spec=["__call__"], return_value=response_iter)
 
@@ -223,23 +369,25 @@ def test_wrap_errors_streaming(wrap_stream_errors):
 @mock.patch(
     "google.auth.default",
     autospec=True,
-    return_value=(mock.sentinel.credentials, mock.sentinel.projet),
+    return_value=(mock.sentinel.credentials, mock.sentinel.project),
 )
 @mock.patch("grpc.secure_channel")
 def test_create_channel_implicit(grpc_secure_channel, default, composite_creds_call):
     target = "example.com:443"
     composite_creds = composite_creds_call.return_value
 
-    channel = grpc_helpers.create_channel(target)
+    channel = grpc_helpers.create_channel(target, compression=grpc.Compression.Gzip)
 
     assert channel is grpc_secure_channel.return_value
 
     default.assert_called_once_with(scopes=None, default_scopes=None)
 
-    if grpc_helpers.HAS_GRPC_GCP:
+    if grpc_helpers.HAS_GRPC_GCP:  # pragma: NO COVER
         grpc_secure_channel.assert_called_once_with(target, composite_creds, None)
     else:
-        grpc_secure_channel.assert_called_once_with(target, composite_creds)
+        grpc_secure_channel.assert_called_once_with(
+            target, composite_creds, compression=grpc.Compression.Gzip
+        )
 
 
 @mock.patch("google.auth.transport.grpc.AuthMetadataPlugin", autospec=True)
@@ -271,17 +419,19 @@ def test_create_channel_implicit_with_default_host(
         mock.sentinel.credentials, mock.sentinel.Request, default_host=default_host
     )
 
-    if grpc_helpers.HAS_GRPC_GCP:
+    if grpc_helpers.HAS_GRPC_GCP:  # pragma: NO COVER
         grpc_secure_channel.assert_called_once_with(target, composite_creds, None)
     else:
-        grpc_secure_channel.assert_called_once_with(target, composite_creds)
+        grpc_secure_channel.assert_called_once_with(
+            target, composite_creds, compression=None
+        )
 
 
 @mock.patch("grpc.composite_channel_credentials")
 @mock.patch(
     "google.auth.default",
     autospec=True,
-    return_value=(mock.sentinel.credentials, mock.sentinel.projet),
+    return_value=(mock.sentinel.credentials, mock.sentinel.project),
 )
 @mock.patch("grpc.secure_channel")
 def test_create_channel_implicit_with_ssl_creds(
@@ -297,17 +447,20 @@ def test_create_channel_implicit_with_ssl_creds(
 
     composite_creds_call.assert_called_once_with(ssl_creds, mock.ANY)
     composite_creds = composite_creds_call.return_value
-    if grpc_helpers.HAS_GRPC_GCP:
+
+    if grpc_helpers.HAS_GRPC_GCP:  # pragma: NO COVER
         grpc_secure_channel.assert_called_once_with(target, composite_creds, None)
     else:
-        grpc_secure_channel.assert_called_once_with(target, composite_creds)
+        grpc_secure_channel.assert_called_once_with(
+            target, composite_creds, compression=None
+        )
 
 
 @mock.patch("grpc.composite_channel_credentials")
 @mock.patch(
     "google.auth.default",
     autospec=True,
-    return_value=(mock.sentinel.credentials, mock.sentinel.projet),
+    return_value=(mock.sentinel.credentials, mock.sentinel.project),
 )
 @mock.patch("grpc.secure_channel")
 def test_create_channel_implicit_with_scopes(
@@ -322,17 +475,19 @@ def test_create_channel_implicit_with_scopes(
 
     default.assert_called_once_with(scopes=["one", "two"], default_scopes=None)
 
-    if grpc_helpers.HAS_GRPC_GCP:
+    if grpc_helpers.HAS_GRPC_GCP:  # pragma: NO COVER
         grpc_secure_channel.assert_called_once_with(target, composite_creds, None)
     else:
-        grpc_secure_channel.assert_called_once_with(target, composite_creds)
+        grpc_secure_channel.assert_called_once_with(
+            target, composite_creds, compression=None
+        )
 
 
 @mock.patch("grpc.composite_channel_credentials")
 @mock.patch(
     "google.auth.default",
     autospec=True,
-    return_value=(mock.sentinel.credentials, mock.sentinel.projet),
+    return_value=(mock.sentinel.credentials, mock.sentinel.project),
 )
 @mock.patch("grpc.secure_channel")
 def test_create_channel_implicit_with_default_scopes(
@@ -347,10 +502,12 @@ def test_create_channel_implicit_with_default_scopes(
 
     default.assert_called_once_with(scopes=None, default_scopes=["three", "four"])
 
-    if grpc_helpers.HAS_GRPC_GCP:
+    if grpc_helpers.HAS_GRPC_GCP:  # pragma: NO COVER
         grpc_secure_channel.assert_called_once_with(target, composite_creds, None)
     else:
-        grpc_secure_channel.assert_called_once_with(target, composite_creds)
+        grpc_secure_channel.assert_called_once_with(
+            target, composite_creds, compression=None
+        )
 
 
 def test_create_channel_explicit_with_duplicate_credentials():
@@ -378,10 +535,13 @@ def test_create_channel_explicit(grpc_secure_channel, auth_creds, composite_cred
     )
 
     assert channel is grpc_secure_channel.return_value
-    if grpc_helpers.HAS_GRPC_GCP:
+
+    if grpc_helpers.HAS_GRPC_GCP:  # pragma: NO COVER
         grpc_secure_channel.assert_called_once_with(target, composite_creds, None)
     else:
-        grpc_secure_channel.assert_called_once_with(target, composite_creds)
+        grpc_secure_channel.assert_called_once_with(
+            target, composite_creds, compression=None
+        )
 
 
 @mock.patch("grpc.composite_channel_credentials")
@@ -401,10 +561,13 @@ def test_create_channel_explicit_scoped(grpc_secure_channel, composite_creds_cal
     credentials.with_scopes.assert_called_once_with(scopes, default_scopes=None)
 
     assert channel is grpc_secure_channel.return_value
-    if grpc_helpers.HAS_GRPC_GCP:
+
+    if grpc_helpers.HAS_GRPC_GCP:  # pragma: NO COVER
         grpc_secure_channel.assert_called_once_with(target, composite_creds, None)
     else:
-        grpc_secure_channel.assert_called_once_with(target, composite_creds)
+        grpc_secure_channel.assert_called_once_with(
+            target, composite_creds, compression=None
+        )
 
 
 @mock.patch("grpc.composite_channel_credentials")
@@ -428,10 +591,13 @@ def test_create_channel_explicit_default_scopes(
     )
 
     assert channel is grpc_secure_channel.return_value
-    if grpc_helpers.HAS_GRPC_GCP:
+
+    if grpc_helpers.HAS_GRPC_GCP:  # pragma: NO COVER
         grpc_secure_channel.assert_called_once_with(target, composite_creds, None)
     else:
-        grpc_secure_channel.assert_called_once_with(target, composite_creds)
+        grpc_secure_channel.assert_called_once_with(
+            target, composite_creds, compression=None
+        )
 
 
 @mock.patch("grpc.composite_channel_credentials")
@@ -453,10 +619,13 @@ def test_create_channel_explicit_with_quota_project(
     credentials.with_quota_project.assert_called_once_with("project-foo")
 
     assert channel is grpc_secure_channel.return_value
-    if grpc_helpers.HAS_GRPC_GCP:
+
+    if grpc_helpers.HAS_GRPC_GCP:  # pragma: NO COVER
         grpc_secure_channel.assert_called_once_with(target, composite_creds, None)
     else:
-        grpc_secure_channel.assert_called_once_with(target, composite_creds)
+        grpc_secure_channel.assert_called_once_with(
+            target, composite_creds, compression=None
+        )
 
 
 @mock.patch("grpc.composite_channel_credentials")
@@ -481,10 +650,13 @@ def test_create_channel_with_credentials_file(
     )
 
     assert channel is grpc_secure_channel.return_value
-    if grpc_helpers.HAS_GRPC_GCP:
+
+    if grpc_helpers.HAS_GRPC_GCP:  # pragma: NO COVER
         grpc_secure_channel.assert_called_once_with(target, composite_creds, None)
     else:
-        grpc_secure_channel.assert_called_once_with(target, composite_creds)
+        grpc_secure_channel.assert_called_once_with(
+            target, composite_creds, compression=None
+        )
 
 
 @mock.patch("grpc.composite_channel_credentials")
@@ -512,10 +684,13 @@ def test_create_channel_with_credentials_file_and_scopes(
     )
 
     assert channel is grpc_secure_channel.return_value
-    if grpc_helpers.HAS_GRPC_GCP:
+
+    if grpc_helpers.HAS_GRPC_GCP:  # pragma: NO COVER
         grpc_secure_channel.assert_called_once_with(target, composite_creds, None)
     else:
-        grpc_secure_channel.assert_called_once_with(target, composite_creds)
+        grpc_secure_channel.assert_called_once_with(
+            target, composite_creds, compression=None
+        )
 
 
 @mock.patch("grpc.composite_channel_credentials")
@@ -543,17 +718,20 @@ def test_create_channel_with_credentials_file_and_default_scopes(
     )
 
     assert channel is grpc_secure_channel.return_value
-    if grpc_helpers.HAS_GRPC_GCP:
+
+    if grpc_helpers.HAS_GRPC_GCP:  # pragma: NO COVER
         grpc_secure_channel.assert_called_once_with(target, composite_creds, None)
     else:
-        grpc_secure_channel.assert_called_once_with(target, composite_creds)
+        grpc_secure_channel.assert_called_once_with(
+            target, composite_creds, compression=None
+        )
 
 
 @pytest.mark.skipif(
     not grpc_helpers.HAS_GRPC_GCP, reason="grpc_gcp module not available"
 )
 @mock.patch("grpc_gcp.secure_channel")
-def test_create_channel_with_grpc_gcp(grpc_gcp_secure_channel):
+def test_create_channel_with_grpc_gcp(grpc_gcp_secure_channel):  # pragma: NO COVER
     target = "example.com:443"
     scopes = ["test_scope"]
 
@@ -676,6 +854,7 @@ class TestChannelStub(object):
         stub = operations_pb2.OperationsStub(channel)
         expected_request = operations_pb2.GetOperationRequest(name="meep")
         expected_response = operations_pb2.Operation(name="moop")
+        expected_compression = grpc.Compression.NoCompression
         expected_metadata = [("red", "blue"), ("two", "shoe")]
         expected_credentials = mock.sentinel.credentials
         channel.GetOperation.response = expected_response
@@ -683,6 +862,7 @@ class TestChannelStub(object):
         response = stub.GetOperation(
             expected_request,
             timeout=42,
+            compression=expected_compression,
             metadata=expected_metadata,
             credentials=expected_credentials,
         )
@@ -690,7 +870,13 @@ class TestChannelStub(object):
         assert response == expected_response
         assert channel.requests == [("GetOperation", expected_request)]
         assert channel.GetOperation.calls == [
-            (expected_request, 42, expected_metadata, expected_credentials)
+            (
+                expected_request,
+                42,
+                expected_metadata,
+                expected_credentials,
+                expected_compression,
+            )
         ]
 
     def test_unary_unary(self):
